# Home Assistant Neon Skill

Uses [PHAL Home Assistant plugin](https://github.com/OpenVoiceOS/ovos-PHAL-plugin-homeassistant)

Still a work in progress - but for turning devices on/off and opening the Home Assistant dashboard (when using neon-gui), it works!

`pip install neon-homeassistant-skill`

## Upcoming Features

- Color settings (still in testing)
- Start OAuth workflow with voice
- Start an instance of the ovos-PHAL-plugin-homeassistant if PHAL isn't already running
